### Snow inspired palettes for your everyday plots

Snow-pal is a fast and easy-to-use color palette dictionary based on real life photos from great winter locations. Try snow-pal and create cool snow figures to share with your colleagues. Snow-pal is compatible with Python 2.7x and 3.4+. 

<img src="https://github.com/brentwilder/snow-pal/blob/master/docs/pals_v1.png" width="1600">
